get file = "hh1.sav"
  /keep hh1 hh2 hh9 cd7 cd9 cd11 cd12a cd12b cd12c cd12d cd12e cd12f cd12g 
	  cd12h cd12i cd12j cd12k cd13.

select if (HH9 = 1).

* select households in which child discipline questionnaire was administered.
select if (not missing(CD12A)).

sort cases by HH1 HH2 CD11.

save out="tmp.sav"
/rename (CD11 = HL1).

get file = "hl1.sav".

sort cases by HH1 HH2 HL1.

match files
  /file = *
  /table = 'tmp.sav'
  /by HH1 HH2 HL1.

weight by hhweight.

select if (HL5 >= 3 and HL5 <= 14 and (not missing(CD12A))).

recode HL5 (3 thru 4 = 1) (5 thru 9 = 2) (10 thru 14 = 3) into agegrp.
variable label agegrp "Age".
value label agegrp
  1 "3-4 years"
  2 "5-9 years"
  3 "10-14 years".

*variable label agegrp "".
*value label agegrp
  1 "3-4 "
  2 "5-9 "
  3 "10-14 ".

compute nviolent = 0.
if ((CD12A = 1 or CD12B = 1 or CD12E = 1) and CD12C = 2 and CD12D = 2 and
  CD12F = 2 and CD12G = 2 and CD12H = 2 and CD12I = 2 and CD12J = 2 and 
	CD12K = 2) nviolent = 100.
variable label nviolent "Only non-violent discipline".
*variable label nviolent "   ".

compute punish = 0.
if (CD12D = 1 or CD12H = 1) punish = 100.
variable label punish "Psychological punishment".
*variable label punish " ".

compute minor = 0.
if (CD12C = 1 or CD12F = 1 or CD12G = 1 or CD12J = 1) minor = 100.
variable label minor "Minor physical punishment".
*variable label minor "  ".

compute severep = 0.
if (CD12I = 1 or CD12K = 1) severep = 100.
variable label Severep "Severe physical punishment".
*variable label Severep "  ".

compute any = 0.
if (punish = 100 or minor = 100 or severep = 100) any = 100.
variable label any "Any psychological or physical punishment *".
*variable label any "  -   *".

compute ndisvio = 0.
if (CD12A = 2 and CD12B = 2 and CD12C = 2 and CD12D = 2 and CD12E = 2 and
  CD12F = 2 and CD12G = 2 and CD12H = 2 and CD12I = 2 and CD12J = 2 and 
	CD12K = 2) ndisvio = 100.
variable label ndisvio "No discipline or punishment".
*variable label ndisvio "    ".

compute ppunish = 0.
if (CD13 = 1) ppunish = 100.
variable label ppunish "Mother/caretaker believes that the child needs to be physically punished".
*variable label ppunish "/  ,       ".

compute layer = 0.
variable label layer "".
value label layer 0 "Percentage of children 3-14 years of age who experience:".
*value label layer 0 "    314 ,  : ".

tables
  /format = zero
  /observation = nviolent punish minor severep any ndisvio ppunish 
  /ftotal = tot1 "Total" tot2 "Number of children aged  3-14 years**"
  /tables = HL4 + HH7 + HH6 + agegrp + melevel + wlthind5 + HC1B + tot1 by 
	  layer > (nviolent + punish + minor + severep + any + ndisvio) + ppunish + tot2
  /statistics
    mean(nviolent (f5.1) '')
    mean(punish (f5.1) '')
    mean(minor (f5.1) '')
    mean(severep (f5.1) '')
    mean(any (f5.1) '')
    mean(ndisvio (f5.1) '')
    mean(ppunish (f5.1) '')
    count(tot2 (f5.0) '')
  /title
    "Table CP.4: Child discipline"
    "Percentage of children aged 3-14 years according to method of disciplining the child, Kyrgyzstan, 2006"
  /caption                                                                                                                                                                          
    "* MICS Indicator 74"
    "** Table is based on children aged 3-14 years randomly selected during fieldwork (one child selected per household, if any children in the age range) for whom the questions on child discipline were administered".

*tables
  /format = zero
  /observation = nviolent punish minor severep any ndisvio ppunish 
  /ftotal = tot1 "" tot2 "    314 **"
  /tables = HL4 + HH7 + HH6 + agegrp + melevel + wlthind5 + HC1B + tot1 by 
	  layer > (nviolent + punish + minor + severep + any + ndisvio) + ppunish + tot2
  /statistics
    mean(nviolent (f5.1) '')
    mean(punish (f5.1) '')
    mean(minor (f5.1) '')
    mean(severep (f5.1) '')
    mean(any (f5.1) '')
    mean(ndisvio (f5.1) '')
    mean(ppunish (f5.1) '')
    count(tot2 (f5.0) '')
  /title
    " CP.4:  "
    "    314       , , 2006"
  /caption                                                                                                                                                                          
    "* MICS Indicator 74"
    "** Table is based on children aged 3-14 years randomly selected during fieldwork (one child selected per household, if any children in the age range) for whom the questions on child discipline were administered".

new file.

* delete working files.
erase file = 'tmp.sav'.
